%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program is used to plot the confusion pattern of normal hearing
% Hearing Impaired 06.
%   Author:      Feipeng Li at HSR, Beckman Institute, UIUC
%   Time-stamp:  2006-10-10
%   E-mail:      fli2@uiuc.edu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plot_MN16R_CP(Table, snrs, cur_snr, Resp, Utter)

% the PI for SNR = -21dB is totally unreliable, get rid of it.
Table = Table(:,2:end); 
snrs = snrs(2:end);

for i=1:length(Resp)
    if strcmp(Resp{i},'noidea')
        Resp{i} = '?';
    else
        Resp(i) = {Resp{i}(1:end-1)};
        if (Resp{i}(1)=='x')
            Resp{i} = upper(Resp{i}(2:end));
        end
    end
end

markers_code = create_markers_code();
             
nRow = length(Resp); nCol = length(snrs);

%scrsz = get(0,'ScreenSize');
%figure('Position',[1 1 scrsz(3)/1.2 scrsz(4)/1.2]);
%figure

p_chance = 1/16;
S = sum(Table(1:nRow, :))+ eps; % total num of presentation 
for j=1:nRow
    if (max(Table(j,:))>1)
        pi_row = Table(j,:)./S;
        idx = find(pi_row<p_chance);
        pi_row(idx) = p_chance;
        
        plot(snrs, log10(pi_row), markers_code{j}.shape, 'Color', markers_code{j}.color,...
            'MarkerFacecolor', markers_code{j}.facecolor, 'MarkerSize', 4 ,'LineWidth',1.5 ); hold on
        p = max(find(Table(j,:)==max(Table(j,:)))); 
        x = snrs(p);  y = Table(j,p)./S(p);
        if (y>p_chance)&&(y<1.1)
            text(double(x), log10(y), Resp(j), 'VerticalAlignment','baseline', 'Color', 'k', 'FontSize', 10, 'FontWeight','bold');
        end
    else
       %plot(snrs, cm1(j,:)./S, '--o', 'Color', color_codes(j-1,:)); hold on
    end
end

hold on
line([cur_snr cur_snr],[.01 1],'Color', 'r' ,'Linewidth', 2, 'Linestyle', '--');
hold off
    
utterance = fix_underscore(Utter);
grid on; xlim([snrs(1)-2,snrs(end)+2]); ylim([log10(1/16), log10(1.05)]); 
title(['Confusion Patterns of ' utterance ], 'FontSize', 9);
set(gca,'XTick',snrs,'FontSize', 9);
set(gca,'YTick',log10([0:0.2:1]),'YTickLabel',[0:0.2:1], 'FontSize', 9);
xlabel('SNR(dB)', 'FontSize', 12); ylabel('nResp/nPresents', 'FontSize', 12); 
%legend(Resp,'Location','EastOutside');
