%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program plot the AIgram 
% Input: AIgram -- the AIgram to be plotted
%        wav_file -- name of the wav file (for labeling)
%        snr -- signal-to-noise ratio for a red line (for labeling)
%        stime -- start time for play the sound
%        etime -- end time for play the sound
%   Author:      Feipeng Li revised from Marion's code
%   E-mail:      fli2@uiuc.edu
%   Time-stamp:  2007-06-05, modified on 2009-05-01
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plot_AI_gram(AIgram, wav_file, snr, stime, etime, fL, fH)

fontsize = 8; 

ccgram = AIgram.ccgram;
time_axis = AIgram.time_axis;
freq_axis = AIgram.freq_axis;

[how_many_filters, how_many_samples] = size(ccgram);
bmdist = linspace(7.35,30,how_many_filters);

imagesc(ccgram); 
colormap(flipud(gray))

set(gca,'YDir','normal')
set(gca,'FontSize',fontsize)
xlabel('Time [cs]','FontSize',fontsize)
ylabel('Frequency [kHz]','FontSize',fontsize)

name = fix_underscore(wav_file);
name = name([2:end]); 

title(sprintf('AI-gram of %s at %d dB SNR',name,snr),'FontSize',fontsize+1)

set(gca,'YAxisLocation','l','YTick',linspace(1,how_many_filters,11));
set(gca,'YTickLabel',0.1*round(10*freq_axis(round(linspace(1,how_many_filters,11)))/1000))
set(gca,'XTick',40*[1:floor(how_many_samples/40)]);
set(gca,'XTickLabel',10*[1:floor(how_many_samples/40)]);

stime_col = round((stime-min(time_axis))/(max(time_axis)-min(time_axis))*how_many_samples);
etime_col = round((etime-min(time_axis))/(max(time_axis)-min(time_axis))*how_many_samples);

err_fL = fL - freq_axis; 
fL_col = find(abs(err_fL)==min(abs(err_fL)));
err_fH = fH - freq_axis; 
fH_col = find(abs(err_fH)==min(abs(err_fH)));
    
hold on
line([stime_col stime_col], [fL_col fH_col], 'Color', 'r' ,'Linewidth', 1, 'Linestyle', '-' );
line([etime_col etime_col], [fL_col fH_col], 'Color', 'r' ,'Linewidth', 1, 'Linestyle', '-' );    
line([stime_col etime_col], [fL_col fL_col], 'Color', 'r' ,'Linewidth', 1, 'Linestyle', '-' );    
line([stime_col etime_col], [fH_col fH_col], 'Color', 'r' ,'Linewidth', 1, 'Linestyle', '-' );    
hold off

% h_axis1 = gca;
% h_axis2=axes('Position',get(h_axis1,'Position'));
% set(h_axis2,'FontSize',fontsize)
% set(h_axis2,'Color','none');
% set(h_axis2,'YAxisLocation','left')
% set(h_axis2,'XTick',[]);
% set(h_axis2,'YLim',get(h_axis1,'YLim'));
% set(h_axis2,'Fontsize', fontsize);
% set(h_axis2,'YTick',get(h_axis1,'YTick'),'FontSize',fontsize);
% set(h_axis2,'YTickLabel',round(bmdist(round(linspace(1,how_many_filters,11)))))
% set(h_axis2,'YAxisLocation','left')
% ylabel('Distance along BM [mm]')