%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program maps a point in STFT space to AIGram
% Input:  t_AI, f_AI -- the coordinates of the point in AIGram space
%         Fs - the sampling frequency
% Output:  t_STFT, f_STFT -- the Look Up Table
%   Author:      Feipeng Li
%   E-mail:      fli2@uiuc.edu
%   Time-stamp:  2007-09-20
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [t_AI, f_AI] = stft2ai(t_STFT, f_STFT, nband_stft, nframe_stft, Fs)

global configs doc;

S = load([configs.syspath '/bin/event_gram/mat/standard.mat']);

nBands_AI = length(S.frequencies);

x_Apex = greenwood_inverse(179.46);
x_Base = greenwood_inverse(7520);

x_AI = linspace( x_Base, x_Apex, nBands_AI);
x_step = (x_Apex-x_Base)/nBands_AI;

freq = f_STFT*(Fs/2/nband_stft);

x = greenwood_inverse(freq);

f_AI = (x - x_Base)/x_step;

f_AI = nBands_AI - f_AI; % reverse frequency

t_AI = t_STFT;      % no change in the time resolution




